Local Atomic Environment Graph Representation (LAEGR).

LAEGR is an open-source Python library for extracting graph structure representation of local atomic environment and building GNN model to predict local/atomic properties.

Install LAGER: pip install laegr

Example folder has the instructions about how to use the LAEGR.

Author: Yi Yao (yyao26@crimson.ua.edu, yyao94@asu.edu), Lin Li.

Relevant works:
